/*
 * SPDX-FileCopyrightText: 2019 Volker Krause <vkrause@kde.org>
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#ifndef GRANTLEETHEME_PALETTE_H
#define GRANTLEETHEME_PALETTE_H

namespace Palette
{
void registerMetaType();
}

#endif // GRANTLEETHEME_PALETTE_H
